@@ -6,20 +6,19 @@
  *
  * Copyright (C) 2002 Gustavo Girldez <gustavo.giraldez@gmx.net>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.  
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -125,14 +124,14 @@ gdl_dock_object_class_init (GdlDockObjectClass *klass)
 
     g_object_class_install_property (
         g_object_class, PROP_LONG_NAME,
-        g_param_spec_string ("long_name", _("Long name"),
+        g_param_spec_string ("long-name", _("Long name"),
                              _("Human readable name for the dock object"),
                              NULL,
                              G_PARAM_READWRITE));
 
     g_object_class_install_property (
         g_object_class, PROP_STOCK_ID,
-        g_param_spec_string ("stock_id", _("Stock Icon"),
+        g_param_spec_string ("stock-id", _("Stock Icon"),
                              _("Stock icon for the dock object"),
                              NULL,
                              G_PARAM_READWRITE));
@@ -354,7 +353,7 @@ gdl_dock_object_real_detach (GdlDockObject *object,
     if (recursive && gdl_dock_object_is_compound (object)) {
         gtk_container_foreach (GTK_CONTAINER (object),
                                (GtkCallback) gdl_dock_object_detach,
-                               (gpointer) recursive);
+                               GINT_TO_POINTER (recursive));
     }
     
     /* detach the object itself */
